summaryrefslogtreecommitdiffstats
path: root/base/synchronization/waitable_event_watcher_win.cc
diff options
context:
space:
mode:
Diffstat (limited to 'base/synchronization/waitable_event_watcher_win.cc')
-rw-r--r--base/synchronization/waitable_event_watcher_win.cc9
1 files changed, 4 insertions, 5 deletions
diff --git a/base/synchronization/waitable_event_watcher_win.cc b/base/synchronization/waitable_event_watcher_win.cc
index dc14e64..f5218f1 100644
--- a/base/synchronization/waitable_event_watcher_win.cc
+++ b/base/synchronization/waitable_event_watcher_win.cc
@@ -5,7 +5,7 @@
#include "base/synchronization/waitable_event_watcher.h"
#include "base/compiler_specific.h"
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "base/synchronization/waitable_event.h"
#include "base/win/object_watcher.h"
@@ -37,10 +37,9 @@ WaitableEvent* WaitableEventWatcher::GetWatchedEvent() {
}
void WaitableEventWatcher::OnObjectSignaled(HANDLE h) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/418183 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "WaitableEventWatche_OnObjectSignaled"));
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/418183 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
+ FROM_HERE_WITH_EXPLICIT_FUNCTION("WaitableEventWatche_OnObjectSignaled"));
WaitableEvent* event = event_;
EventCallback callback = callback_;